@@ -38,8 +38,8 @@ const allFlag = "all"
 // cacheCmd represents the cache command
 var cacheCmd = &cobra.Command{
 	Use:   "cache",
-	Short: "Add, delete, or push a local image into minikube",
-	Long:  "Add, delete, or push a local image into minikube",
+	Short: "Manage cache for images",
+	Long:  "Add an image into minikube as a local cache, or delete, reload the cached images",
 }
 
 // addCacheCmd represents the cache add command
@@ -47,7 +47,7 @@ var addCacheCmd = &cobra.Command{
 	Use:   "add",
 	Short: "Add an image to local cache.",
 	Long:  "Add an image to local cache.",
-	Run: func(cmd *cobra.Command, args []string) {
+	Run: func(_ *cobra.Command, args []string) {
 		out.WarningT("\"minikube cache\" will be deprecated in upcoming versions, please switch to \"minikube image load\"")
 		// Cache and load images into docker daemon
 		if err := machine.CacheAndLoadImages(args, cacheAddProfiles(), false); err != nil {
@@ -85,7 +85,7 @@ var deleteCacheCmd = &cobra.Command{
 	Use:   "delete",
 	Short: "Delete an image from the local cache.",
 	Long:  "Delete an image from the local cache.",
-	Run: func(cmd *cobra.Command, args []string) {
+	Run: func(_ *cobra.Command, args []string) {
 		// Delete images from config file
 		if err := cmdConfig.DeleteFromConfigMap(cacheImageConfigKey, args); err != nil {
 			exit.Error(reason.InternalDelConfig, "Failed to delete images from config", err)
@@ -102,7 +102,7 @@ var reloadCacheCmd = &cobra.Command{
 	Use:   "reload",
 	Short: "reload cached images.",
 	Long:  "reloads images previously added using the 'cache add' subcommand",
-	Run: func(cmd *cobra.Command, args []string) {
+	Run: func(_ *cobra.Command, _ []string) {
 		err := node.CacheAndLoadImagesInConfig(cacheAddProfiles())
 		if err != nil {
 			exit.Error(reason.GuestCacheLoad, "Failed to reload cached images", err)
