@@ -40,7 +40,9 @@ type ViewTemplate struct {
 var configViewCmd = &cobra.Command{
 	Use:   "view",
 	Short: "Display values currently set in the minikube config file",
-	Long:  "Display values currently set in the minikube config file.",
+	Long:  `Display values currently set in the minikube config file. 
+	The output format can be customized using the --format flag, which accepts a Go template. 
+	The config file is typically located at "~/.minikube/config/config.json".`,
 	Run: func(_ *cobra.Command, _ []string) {
 		err := View()
 		if err != nil {
