@@ -163,18 +163,20 @@ You may select another namespace by using 'minikube service {{.service}} -n <nam
 		for _, svc := range noNodePortServices {
 			noNodePortSvcNames = append(noNodePortSvcNames, fmt.Sprintf("%s/%s", svc.Namespace, svc.Name))
 		}
-		if len(noNodePortServices) != 0 {
+		if len(noNodePortServices) > 0 {
 			out.WarningT("Services {{.svc_names}} have type \"ClusterIP\" not meant to be exposed, however for local development minikube allows you to access this !", out.V{"svc_names": noNodePortSvcNames})
 		}
 
-		if driver.NeedsPortForward(co.Config.Driver) && services != nil {
-			startKicServiceTunnel(services, cname, co.Config.Driver)
+		if driver.NeedsPortForward(co.Config.Driver) {
+			svcs := services
+			if len(svcs) == 0 && len(noNodePortServices) > 0 {
+				svcs = noNodePortServices
+			}
+			if len(svcs) > 0 {
+				startKicServiceTunnel(svcs, cname, co.Config.Driver)
+			}
 		} else if !serviceURLMode {
 			openURLs(data)
-			if len(noNodePortServices) != 0 {
-				startKicServiceTunnel(noNodePortServices, cname, co.Config.Driver)
-			}
-
 		}
 	},
 }
