@@ -62,11 +62,13 @@ func execute() error {
 	p := plot.New()
 
 	// Set view options
-	if runtime.GOOS == "darwin" {
+	switch runtime.GOOS {
+	case "darwin":
 		p.Title.Text = "CPU% Busy Overhead - Average first 5 minutes on macOS (less is better)"
-	} else if runtime.GOOS == "linux" {
+	case "linux":
 		p.Title.Text = "CPU% Busy Overhead - Average first 5 minutes on Linux (less is better)"
 	}
+
 	p.Y.Label.Text = "CPU overhead%"
 
 	// Open csv file of benchmark summary
@@ -114,9 +116,10 @@ func execute() error {
 	p.Legend.Top = true
 
 	// Add x-lay names
-	if runtime.GOOS == "darwin" {
+	switch runtime.GOOS {
+	case "darwin":
 		p.NominalX("OS idle", "minikube hyperkit", "minikube virtualbox", "minikube docker", "Docker for Mac Kubernetes", "k3d", "kind")
-	} else if runtime.GOOS == "linux" {
+	case "linux":
 		p.NominalX("OS idle", "minikube kvm2", "minikube virtualbox", "minikube docker", "Docker idle", "k3d", "kind")
 	}
 
@@ -151,16 +154,18 @@ func execute() error {
 	p.Add(cl)
 
 	// Output bar graph
-	if runtime.GOOS == "darwin" {
+	switch runtime.GOOS {
+	case "darwin":
 		if err := p.Save(13*vg.Inch, 8*vg.Inch, FOLDER+"/mac.png"); err != nil {
 			return errors.Wrap(err, "Failed to create bar graph png")
 		}
 		log.Printf("Generated graph png to %s/mac.png", FOLDER)
-	} else if runtime.GOOS == "linux" {
+	case "linux":
 		if err := p.Save(13*vg.Inch, 10*vg.Inch, FOLDER+"/linux.png"); err != nil {
 			return errors.Wrap(err, "Failed to create bar graph png")
 		}
 		log.Printf("Generated graph png to %s/linux.png", FOLDER)
 	}
+
 	return nil
 }
