@@ -25,17 +25,17 @@ import (
 )
 
 func main() {
-	if err := os.MkdirAll("./out/docs", os.FileMode(0755)); err != nil {
+	if err := os.MkdirAll("../out/docs", os.FileMode(0755)); err != nil {
 		fmt.Println(err)
 		os.Exit(1)
 	}
 	cmd.RootCmd.DisableAutoGenTag = true
-	if err := doc.GenMarkdownTree(cmd.RootCmd, "./out/docs"); err != nil {
+	if err := doc.GenMarkdownTree(cmd.RootCmd, "../out/docs"); err != nil {
 		fmt.Println(err)
 		os.Exit(1)
 	}
 
-	f, err := os.Create("./out/docs/bash-completion")
+	f, err := os.Create("../out/docs/bash-completion")
 	if err != nil {
 		fmt.Println(err)
 		os.Exit(1)
