@@ -21,7 +21,7 @@
 # MINIKUBE_LOCATION: GIT_COMMIT from upstream build.
 # COMMIT: Actual commit ID from upstream build
 # EXTRA_BUILD_ARGS (optional): Extra args to be passed into the minikube integrations tests
-# access_token: The Github API access token. Injected by the Jenkins credential provider. 
+# access_token: The GitHub API access token. Injected by the Jenkins credential provider.
 
 set -e
 
@@ -31,11 +31,6 @@ DRIVER="kvm2"
 JOB_NAME="KVM_Linux_crio"
 CONTAINER_RUNTIME="crio"
 
-
-
-mkdir -p cron && gsutil -qm rsync "gs://minikube-builds/${MINIKUBE_LOCATION}/cron" cron || echo "FAILED TO GET CRON FILES"
-sudo install cron/cleanup_and_reboot_Linux.sh /etc/cron.hourly/cleanup_and_reboot || echo "FAILED TO INSTALL CLEANUP"
-
 sudo apt-get update
 sudo apt-get -y install qemu-system libvirt-clients libvirt-daemon-system ebtables iptables dnsmasq
 sudo adduser jenkins libvirt || true
