@@ -27,11 +27,11 @@ import (
 	"time"
 
 	_ "cloud.google.com/go/storage"
-	"contrib.go.opencensus.io/exporter/stackdriver"
+	mexporter "github.com/GoogleCloudPlatform/opentelemetry-operations-go/exporter/metric"
 	"github.com/pkg/errors"
-	"go.opencensus.io/stats"
-	"go.opencensus.io/stats/view"
-	"go.opencensus.io/trace"
+	"go.opentelemetry.io/otel/attribute"
+	"go.opentelemetry.io/otel/metric"
+	sdkmetric "go.opentelemetry.io/otel/sdk/metric"
 	pkgtrace "k8s.io/minikube/pkg/trace"
 )
 
@@ -41,10 +41,8 @@ const (
 )
 
 var (
-	// The task latency in seconds
-	latencyS = stats.Float64("repl/start_time", "start time in seconds", "s")
-	labels   string
-	tmpFile  string
+	labels  string
+	tmpFile string
 )
 
 func main() {
@@ -70,17 +68,6 @@ func execute() error {
 		return errors.Wrap(err, "downloading minikube")
 	}
 
-	// Register the view. It is imperative that this step exists,
-	// otherwise recorded metrics will be dropped and never exported.
-	v := &view.View{
-		Name:        customMetricName,
-		Measure:     latencyS,
-		Description: "minikube start time",
-		Aggregation: view.LastValue(),
-	}
-	if err := view.Register(v); err != nil {
-		return errors.Wrap(err, "registering view")
-	}
 	for _, cr := range []string{"docker", "containerd", "crio"} {
 		if err := exportMinikubeStart(ctx, projectID, cr); err != nil {
 			log.Printf("error exporting minikube start data for runtime %v: %v", cr, err)
@@ -90,45 +77,42 @@ func execute() error {
 }
 
 func exportMinikubeStart(ctx context.Context, projectID, containerRuntime string) error {
-	sd, err := getExporter(projectID, containerRuntime)
+	mp, attrs, err := getMeterProvider(projectID, containerRuntime)
 	if err != nil {
-		return errors.Wrap(err, "getting stackdriver exporter")
+		return errors.Wrap(err, "creating meter provider")
 	}
-	// Register it as a trace exporter
-	trace.RegisterExporter(sd)
+	defer func() { _ = mp.Shutdown(ctx) }()
 
-	if err := sd.StartMetricsExporter(); err != nil {
-		return errors.Wrap(err, "starting metric exporter")
+	meter := mp.Meter("minikube")
+	latency, err := meter.Float64Histogram(customMetricName)
+	if err != nil {
+		return errors.Wrap(err, "creating histogram")
 	}
-	// track minikube start time and record it to metrics collector
+
 	st, err := minikubeStartTime(ctx, projectID, tmpFile, containerRuntime)
 	if err != nil {
 		return errors.Wrap(err, "collecting start time")
 	}
 	fmt.Printf("Latency: %f\n", st)
-	stats.Record(ctx, latencyS.M(st))
+	latency.Record(ctx, st, metric.WithAttributes(attrs...))
 	time.Sleep(30 * time.Second)
-	sd.Flush()
-	sd.StopMetricsExporter()
-	trace.UnregisterExporter(sd)
 	return nil
 }
 
-func getExporter(projectID, containerRuntime string) (*stackdriver.Exporter, error) {
-	return stackdriver.NewExporter(stackdriver.Options{
-		ProjectID: projectID,
-		// ReportingInterval sets the frequency of reporting metrics
-		// to stackdriver backend.
-		ReportingInterval:       11 * time.Second,
-		DefaultMonitoringLabels: getLabels(containerRuntime),
-	})
+func getMeterProvider(projectID, containerRuntime string) (*sdkmetric.MeterProvider, []attribute.KeyValue, error) {
+	exporter, err := mexporter.New(mexporter.WithProjectID(projectID))
+	if err != nil {
+		return nil, nil, err
+	}
+	reader := sdkmetric.NewPeriodicReader(exporter, sdkmetric.WithInterval(11*time.Second))
+	mp := sdkmetric.NewMeterProvider(sdkmetric.WithReader(reader))
+	return mp, getAttributes(containerRuntime), nil
 }
 
-func getLabels(containerRuntime string) *stackdriver.Labels {
-	l := &stackdriver.Labels{}
-	l.Set("container-runtime", containerRuntime, "container-runtime")
+func getAttributes(containerRuntime string) []attribute.KeyValue {
+	attrs := []attribute.KeyValue{attribute.String("container-runtime", containerRuntime)}
 	if labels == "" {
-		return l
+		return attrs
 	}
 	separated := strings.Split(labels, ",")
 	for _, s := range separated {
@@ -137,15 +121,15 @@ func getLabels(containerRuntime string) *stackdriver.Labels {
 			continue
 		}
 		log.Printf("Adding label %s=%s to metrics...", sep[0], sep[1])
-		l.Set(sep[0], sep[1], "")
+		attrs = append(attrs, attribute.String(sep[0], sep[1]))
 	}
-	return l
+	return attrs
 }
 
 func minikubeStartTime(ctx context.Context, projectID, minikubePath, containerRuntime string) (float64, error) {
 	defer deleteMinikube(ctx, minikubePath)
 
-	cmd := exec.CommandContext(ctx, minikubePath, "start", "--driver=docker", "-p", profile, "--memory=2048", "--trace=gcp", fmt.Sprintf("--container-runtime=%s", containerRuntime))
+	cmd := exec.CommandContext(ctx, minikubePath, "start", "--driver=docker", "-p", profile, "--memory=3072", "--trace=gcp", fmt.Sprintf("--container-runtime=%s", containerRuntime))
 	cmd.Env = append(os.Environ(), fmt.Sprintf("%s=%s", pkgtrace.ProjectEnvVar, projectID))
 	cmd.Stdout = os.Stderr
 	cmd.Stderr = os.Stderr
