@@ -17,8 +17,8 @@ limitations under the License.
 package addons
 
 import (
+	"errors"
 	"fmt"
-	"runtime"
 	"strconv"
 
 	"github.com/spf13/viper"
@@ -47,22 +47,21 @@ const volumesnapshotsDisabledMsg = `[WARNING] For full functionality, the 'csi-h
 You can enable 'volumesnapshots' addon by running: 'minikube addons enable volumesnapshots'
 `
 
-// IsRuntimeContainerd is a validator which returns an error if the current runtime is not containerd
-func IsRuntimeContainerd(cc *config.ClusterConfig, _, _ string) error {
+func isRuntimeContainerd(cc *config.ClusterConfig, _, _ string) error {
 	r, err := cruntime.New(cruntime.Config{Type: cc.KubernetesConfig.ContainerRuntime})
 	if err != nil {
 		return err
 	}
 	_, ok := r.(*cruntime.Containerd)
 	if !ok {
-		return fmt.Errorf(containerdOnlyAddonMsg)
+		return errors.New(containerdOnlyAddonMsg)
 	}
 	return nil
 }
 
-// IsVolumesnapshotsEnabled is a validator that prints out a warning if the volumesnapshots addon
+// isVolumesnapshotsEnabled is a validator that prints out a warning if the volumesnapshots addon
 // is disabled (does not return any errors!)
-func IsVolumesnapshotsEnabled(cc *config.ClusterConfig, _, value string) error {
+func isVolumesnapshotsEnabled(cc *config.ClusterConfig, _, value string) error {
 	isCsiDriverEnabled, _ := strconv.ParseBool(value)
 	// assets.Addons[].IsEnabled() returns the current status of the addon or default value.
 	// config.AddonList contains list of addons to be enabled.
@@ -76,6 +75,15 @@ func IsVolumesnapshotsEnabled(cc *config.ClusterConfig, _, value string) error {
 	return nil
 }
 
+func isKVMDriverForNVIDIA(cc *config.ClusterConfig, name, _ string) error {
+	if driver.IsKVM(cc.Driver) {
+		return nil
+	}
+	out.Ln("")
+	out.FailureT("The {{.addon}} addon is only supported with the KVM driver.\n\nFor GPU setup instructions see: https://minikube.sigs.k8s.io/docs/tutorials/nvidia/", out.V{"addon": name})
+	return fmt.Errorf("%s addon is only supported with the KVM driver", name)
+}
+
 // isAddonValid returns the addon, true if it is valid
 // otherwise returns nil, false
 func isAddonValid(name string) (*Addon, bool) {
@@ -95,15 +103,3 @@ func contains(slice []string, val string) bool {
 	}
 	return false
 }
-
-// SupportsAmd64 ensures that the cluster supports running amd64 images
-func SupportsAmd64(cc *config.ClusterConfig, name, _ string) error {
-	// KIC can run amd64 images on a non-amd64 environment
-	if driver.IsKIC(cc.Driver) {
-		return nil
-	}
-	if runtime.GOARCH == "amd64" {
-		return nil
-	}
-	return fmt.Errorf("the %q addon requires a cluster that supports running amd64 images", name)
-}
