@@ -1,5 +1,4 @@
 //go:build !linux
-// +build !linux
 
 /*
 Copyright 2021 The Kubernetes Authors All rights reserved.
@@ -19,13 +18,10 @@ limitations under the License.
 
 package oci
 
-import (
-	"runtime"
+func HasMemoryCgroup() bool {
+	return true
+}
 
-	"github.com/pkg/errors"
-)
-
-// IsCgroup2UnifiedMode returns whether we are running in cgroup 2 cgroup2 mode.
-func IsCgroup2UnifiedMode() (bool, error) {
-	return false, errors.Errorf("Not supported on %s", runtime.GOOS)
+func hasMemorySwapCgroup() bool {
+	return true
 }
