@@ -39,13 +39,13 @@ const networkTmpl = `
 <network>
   <name>{{.Name}}</name>
   <dns enable='no'/>
-  {{with .Parameters}}
+  {{- with .Parameters}}
   <ip address='{{.Gateway}}' netmask='{{.Netmask}}'>
     <dhcp>
       <range start='{{.ClientMin}}' end='{{.ClientMax}}'/>
     </dhcp>
   </ip>
-  {{end}}
+  {{- end}}
 </network>
 `
 
@@ -84,9 +84,15 @@ const firstSubnetAddr = "192.168.39.0"
 func setupNetwork(conn *libvirt.Connect, name string) error {
 	n, err := conn.LookupNetworkByName(name)
 	if err != nil {
-		return errors.Wrapf(err, "checking network %s", name)
+		return fmt.Errorf("failed looking up network %s: %w", name, lvErr(err))
 	}
-	defer func() { _ = n.Free() }()
+	defer func() {
+		if n == nil {
+			log.Warnf("nil network, cannot free")
+		} else if err := n.Free(); err != nil {
+			log.Errorf("failed freeing %s network: %v", name, lvErr(err))
+		}
+	}()
 
 	// always ensure autostart is set on the network
 	autostart, err := n.GetAutostart()
@@ -104,7 +110,9 @@ func setupNetwork(conn *libvirt.Connect, name string) error {
 	if err != nil {
 		return errors.Wrapf(err, "checking network status for %s", name)
 	}
+
 	if !active {
+		log.Debugf("network %s is not active, trying to start it...", name)
 		if err := n.Create(); err != nil {
 			return errors.Wrapf(err, "starting network %s", name)
 		}
@@ -116,11 +124,11 @@ func setupNetwork(conn *libvirt.Connect, name string) error {
 func (d *Driver) ensureNetwork() error {
 	conn, err := getConnection(d.ConnectionURI)
 	if err != nil {
-		return errors.Wrap(err, "getting libvirt connection")
+		return fmt.Errorf("failed opening libvirt connection: %w", err)
 	}
 	defer func() {
 		if _, err := conn.Close(); err != nil {
-			log.Errorf("unable to close libvirt connection: %v", err)
+			log.Errorf("failed closing libvirt connection: %v", lvErr(err))
 		}
 	}()
 
@@ -164,11 +172,11 @@ func (d *Driver) createNetwork() error {
 
 	conn, err := getConnection(d.ConnectionURI)
 	if err != nil {
-		return errors.Wrap(err, "getting libvirt connection")
+		return fmt.Errorf("failed opening libvirt connection: %w", err)
 	}
 	defer func() {
 		if _, err := conn.Close(); err != nil {
-			log.Errorf("unable to close libvirt connection: %v", err)
+			log.Errorf("failed closing libvirt connection: %v", lvErr(err))
 		}
 	}()
 
@@ -176,23 +184,34 @@ func (d *Driver) createNetwork() error {
 	// It is assumed that the libvirt/kvm installation has already created this network
 	netd, err := conn.LookupNetworkByName(d.Network)
 	if err != nil {
-		return errors.Wrapf(err, "%s KVM network doesn't exist", d.Network)
+		return fmt.Errorf("failed looking up network %s, cannot continue: %w", d.Network, lvErr(err))
 	}
-	log.Debugf("found existing %s KVM network", d.Network)
-	if netd != nil {
-		_ = netd.Free()
+	log.Debugf("found existing %s network", d.Network)
+
+	if netdXML, err := netd.GetXMLDesc(0); err != nil {
+		log.Debugf("failed getting %s network XML: %v", d.Network, lvErr(err))
+	} else {
+		log.Debug(netdXML)
+	}
+
+	if err := netd.Free(); err != nil {
+		log.Errorf("failed freeing %s network: %v", d.Network, lvErr(err))
 	}
 
 	// network: private
 	// Only create the private network if it does not already exist
-	netp, err := conn.LookupNetworkByName(d.PrivateNetwork)
-	defer func() {
-		if netp != nil {
-			_ = netp.Free()
+	if netp, err := conn.LookupNetworkByName(d.PrivateNetwork); err == nil {
+		log.Warnf("found existing %s private network, skipping creation", d.PrivateNetwork)
+
+		if netpXML, err := netp.GetXMLDesc(0); err != nil {
+			log.Debugf("failed getting %s private network XML: %v", d.PrivateNetwork, lvErr(err))
+		} else {
+			log.Debug(netpXML)
+		}
+
+		if err := netp.Free(); err != nil {
+			log.Errorf("failed freeing %s private network: %v", d.PrivateNetwork, lvErr(err))
 		}
-	}()
-	if err == nil {
-		log.Debugf("found existing private KVM network %s", d.PrivateNetwork)
 		return nil
 	}
 
@@ -203,7 +222,7 @@ func (d *Driver) createNetwork() error {
 		var subnet *network.Parameters
 		subnet, err = network.FreeSubnet(subnetAddr, 11, 20)
 		if err != nil {
-			log.Debugf("failed to find free subnet for private KVM network %s after %d attempts: %v", d.PrivateNetwork, 20, err)
+			log.Debugf("failed finding free subnet for private network %s after %d attempts: %v", d.PrivateNetwork, 20, err)
 			return fmt.Errorf("un-retryable: %w", err)
 		}
 
@@ -220,37 +239,42 @@ func (d *Driver) createNetwork() error {
 		tmpl := template.Must(template.New("network").Parse(networkTmpl))
 		var networkXML bytes.Buffer
 		if err = tmpl.Execute(&networkXML, tryNet); err != nil {
-			return fmt.Errorf("executing private KVM network template: %w", err)
+			return fmt.Errorf("executing private network template: %w", err)
 		}
-		log.Debugf("created network xml: %s", networkXML.String())
 
 		// define the network using our template
-		var network *libvirt.Network
-		network, err = conn.NetworkDefineXML(networkXML.String())
+		log.Debugf("defining private network:\n%s", networkXML.String())
+		libvirtNet, err := conn.NetworkDefineXML(networkXML.String())
 		if err != nil {
-			return fmt.Errorf("defining private KVM network %s %s from xml %s: %w", d.PrivateNetwork, subnet.CIDR, networkXML.String(), err)
+			return fmt.Errorf("defining private network %s %s from xml %s: %w", d.PrivateNetwork, subnet.CIDR, networkXML.String(), err)
 		}
 
 		// and finally create & start it
-		log.Debugf("trying to create private KVM network %s %s...", d.PrivateNetwork, subnet.CIDR)
-		if err = network.Create(); err == nil {
-			log.Debugf("private KVM network %s %s created", d.PrivateNetwork, subnet.CIDR)
+		log.Debugf("creating private network %s %s...", d.PrivateNetwork, subnet.CIDR)
+		if err = libvirtNet.Create(); err == nil {
+			log.Debugf("private network %s %s created", d.PrivateNetwork, subnet.CIDR)
+			if netpXML, err := libvirtNet.GetXMLDesc(0); err != nil {
+				log.Debugf("failed getting %s private network XML: %v", d.PrivateNetwork, lvErr(err))
+			} else {
+				log.Debug(netpXML)
+			}
+
 			return nil
 		}
-		log.Debugf("failed to create private KVM network %s %s, will retry: %v", d.PrivateNetwork, subnet.CIDR, err)
+		log.Debugf("failed creating private network %s %s, will retry: %v", d.PrivateNetwork, subnet.CIDR, err)
 		subnetAddr = subnet.IP
 	}
-	return fmt.Errorf("failed to create private KVM network %s: %w", d.PrivateNetwork, err)
+	return fmt.Errorf("failed creating private network %s: %w", d.PrivateNetwork, err)
 }
 
 func (d *Driver) deleteNetwork() error {
 	conn, err := getConnection(d.ConnectionURI)
 	if err != nil {
-		return errors.Wrap(err, "getting libvirt connection")
+		return fmt.Errorf("failed opening libvirt connection: %w", err)
 	}
 	defer func() {
 		if _, err := conn.Close(); err != nil {
-			log.Errorf("unable to close libvirt connection: %v", err)
+			log.Errorf("failed closing libvirt connection: %v", lvErr(err))
 		}
 	}()
 
@@ -263,7 +287,7 @@ func (d *Driver) deleteNetwork() error {
 
 	// network: private
 	log.Debugf("Checking if network %s exists...", d.PrivateNetwork)
-	network, err := conn.LookupNetworkByName(d.PrivateNetwork)
+	libvirtNet, err := conn.LookupNetworkByName(d.PrivateNetwork)
 	if err != nil {
 		if lvErr(err).Code == libvirt.ERR_NO_NETWORK {
 			log.Warnf("Network %s does not exist. Skipping deletion", d.PrivateNetwork)
@@ -271,7 +295,14 @@ func (d *Driver) deleteNetwork() error {
 		}
 		return errors.Wrapf(err, "failed looking up network %s", d.PrivateNetwork)
 	}
-	defer func() { _ = network.Free() }()
+	defer func() {
+		if libvirtNet == nil {
+			log.Warnf("nil network, cannot free")
+		} else if err := libvirtNet.Free(); err != nil {
+			log.Errorf("failed freeing %s network: %v", d.PrivateNetwork, lvErr(err))
+		}
+	}()
+
 	log.Debugf("Network %s exists", d.PrivateNetwork)
 
 	err = d.checkDomains(conn)
@@ -283,18 +314,18 @@ func (d *Driver) deleteNetwork() error {
 
 	log.Debugf("Trying to delete network %s...", d.PrivateNetwork)
 	deleteFunc := func() error {
-		active, err := network.IsActive()
+		active, err := libvirtNet.IsActive()
 		if err != nil {
 			return err
 		}
 		if active {
 			log.Debugf("Destroying active network %s", d.PrivateNetwork)
-			if err := network.Destroy(); err != nil {
+			if err := libvirtNet.Destroy(); err != nil {
 				return err
 			}
 		}
 		log.Debugf("Undefining inactive network %s", d.PrivateNetwork)
-		return network.Undefine()
+		return libvirtNet.Undefine()
 	}
 	if err := retry.Local(deleteFunc, 10*time.Second); err != nil {
 		return errors.Wrap(err, "deleting network")
@@ -391,23 +422,29 @@ func (d *Driver) checkDomains(conn *libvirt.Connect) error {
 
 // addStaticIP appends new host's name, MAC and static IP address record to list of network DHCP leases.
 // It will return nil if host record already exists.
-func addStaticIP(conn *libvirt.Connect, network, hostname, mac, ip string) error {
-	l, err := dhcpLease(conn, network, hostname, mac, ip)
+func addStaticIP(conn *libvirt.Connect, networkName, hostname, mac, ip string) error {
+	l, err := dhcpLease(conn, networkName, hostname, mac, ip)
 	if err != nil {
-		return fmt.Errorf("failed looking up network %s for host DHCP lease {name: %q, mac: %q, ip: %q}: %w", network, hostname, mac, ip, err)
+		return fmt.Errorf("failed looking up network %s for host DHCP lease {name: %q, mac: %q, ip: %q}: %w", networkName, hostname, mac, ip, err)
 	}
 	if l != nil {
-		log.Debugf("skip adding static IP to network %s - found existing host DHCP lease matching {name: %q, mac: %q, ip: %q}", network, hostname, mac, ip)
+		log.Debugf("skip adding static IP to network %s - found existing host DHCP lease matching {name: %q, mac: %q, ip: %q}", networkName, hostname, mac, ip)
 		return nil
 	}
 
-	net, err := conn.LookupNetworkByName(network)
+	libvirtNet, err := conn.LookupNetworkByName(networkName)
 	if err != nil {
-		return fmt.Errorf("failed looking up network %s: %w", network, err)
+		return fmt.Errorf("failed looking up network %s: %w", networkName, err)
 	}
-	defer func() { _ = net.Free() }()
+	defer func() {
+		if libvirtNet == nil {
+			log.Warnf("nil network, cannot free")
+		} else if err := libvirtNet.Free(); err != nil {
+			log.Errorf("failed freeing %s network: %v", networkName, lvErr(err))
+		}
+	}()
 
-	return net.Update(
+	return libvirtNet.Update(
 		libvirt.NETWORK_UPDATE_COMMAND_ADD_LAST,
 		libvirt.NETWORK_SECTION_IP_DHCP_HOST,
 		-1,
@@ -417,23 +454,29 @@ func addStaticIP(conn *libvirt.Connect, network, hostname, mac, ip string) error
 
 // delStaticIP deletes static IP address record that matches given combination of host's name, MAC and IP from list of network DHCP leases.
 // It will return nil if record doesn't exist.
-func delStaticIP(conn *libvirt.Connect, network, hostname, mac, ip string) error {
-	l, err := dhcpLease(conn, network, hostname, mac, ip)
+func delStaticIP(conn *libvirt.Connect, networkName, hostname, mac, ip string) error {
+	l, err := dhcpLease(conn, networkName, hostname, mac, ip)
 	if err != nil {
-		return fmt.Errorf("failed looking up network %s for host DHCP lease {name: %q, mac: %q, ip: %q}: %w", network, hostname, mac, ip, err)
+		return fmt.Errorf("failed looking up network %s for host DHCP lease {name: %q, mac: %q, ip: %q}: %w", networkName, hostname, mac, ip, err)
 	}
 	if l == nil {
-		log.Debugf("skip deleting static IP from network %s - couldn't find host DHCP lease matching {name: %q, mac: %q, ip: %q}", network, hostname, mac, ip)
+		log.Debugf("skip deleting static IP from network %s - couldn't find host DHCP lease matching {name: %q, mac: %q, ip: %q}", networkName, hostname, mac, ip)
 		return nil
 	}
 
-	net, err := conn.LookupNetworkByName(network)
+	libvirtNet, err := conn.LookupNetworkByName(networkName)
 	if err != nil {
-		return fmt.Errorf("failed looking up network %s: %w", network, err)
+		return fmt.Errorf("failed looking up network %s: %w", networkName, err)
 	}
-	defer func() { _ = net.Free() }()
+	defer func() {
+		if libvirtNet == nil {
+			log.Warnf("nil network, cannot free")
+		} else if err := libvirtNet.Free(); err != nil {
+			log.Errorf("failed freeing %s network: %v", networkName, lvErr(err))
+		}
+	}()
 
-	return net.Update(
+	return libvirtNet.Update(
 		libvirt.NETWORK_UPDATE_COMMAND_DELETE,
 		libvirt.NETWORK_SECTION_IP_DHCP_HOST,
 		-1,
@@ -442,56 +485,62 @@ func delStaticIP(conn *libvirt.Connect, network, hostname, mac, ip string) error
 }
 
 // dhcpLease returns network DHCP lease that matches given combination of host's name, MAC and IP.
-func dhcpLease(conn *libvirt.Connect, network, hostname, mac, ip string) (lease *libvirt.NetworkDHCPLease, err error) {
+func dhcpLease(conn *libvirt.Connect, networkName, hostname, mac, ip string) (lease *libvirt.NetworkDHCPLease, err error) {
 	if hostname == "" && mac == "" && ip == "" {
 		return nil, nil
 	}
 
-	net, err := conn.LookupNetworkByName(network)
+	libvirtNet, err := conn.LookupNetworkByName(networkName)
 	if err != nil {
-		return nil, fmt.Errorf("failed looking up network %s: %w", network, err)
+		return nil, fmt.Errorf("failed looking up network %s: %w", networkName, err)
 	}
-	defer func() { _ = net.Free() }()
+	defer func() {
+		if libvirtNet == nil {
+			log.Warnf("nil network, cannot free")
+		} else if err := libvirtNet.Free(); err != nil {
+			log.Errorf("failed freeing %s network: %v", networkName, lvErr(err))
+		}
+	}()
 
-	leases, err := net.GetDHCPLeases()
+	leases, err := libvirtNet.GetDHCPLeases()
 	if err != nil {
 		return nil, fmt.Errorf("failed getting host DHCP leases: %w", err)
 	}
 
 	for _, l := range leases {
 		if (hostname == "" || hostname == l.Hostname) && (mac == "" || mac == l.Mac) && (ip == "" || ip == l.IPaddr) {
-			log.Debugf("found host DHCP lease matching {name: %q, mac: %q, ip: %q} in network %s: %+v", hostname, mac, ip, network, l)
+			log.Debugf("found host DHCP lease matching {name: %q, mac: %q, ip: %q} in network %s: %+v", hostname, mac, ip, networkName, l)
 			return &l, nil
 		}
 	}
 
-	log.Debugf("unable to find host DHCP lease matching {name: %q, mac: %q, ip: %q} in network %s", hostname, mac, ip, network)
+	log.Debugf("unable to find host DHCP lease matching {name: %q, mac: %q, ip: %q} in network %s", hostname, mac, ip, networkName)
 	return nil, nil
 }
 
 // ipFromAPI returns current primary IP address of domain interface in network.
-func ipFromAPI(conn *libvirt.Connect, domain, network string) (string, error) {
-	mac, err := macFromXML(conn, domain, network)
+func ipFromAPI(conn *libvirt.Connect, domain, networkName string) (string, error) {
+	mac, err := macFromXML(conn, domain, networkName)
 	if err != nil {
 		return "", fmt.Errorf("failed getting MAC address: %w", err)
 	}
 
 	ifaces, err := ifListFromAPI(conn, domain)
 	if err != nil {
-		return "", fmt.Errorf("failed getting network %s interfaces using API of domain %s: %w", network, domain, err)
+		return "", fmt.Errorf("failed getting network %s interfaces using API of domain %s: %w", networkName, domain, err)
 	}
 	for _, i := range ifaces {
 		if i.Hwaddr == mac {
 			if i.Addrs != nil {
-				log.Debugf("domain %s has current primary IP address %s and MAC address %s in network %s", domain, i.Addrs[0].Addr, mac, network)
+				log.Debugf("domain %s has current primary IP address %s and MAC address %s in network %s", domain, i.Addrs[0].Addr, mac, networkName)
 				return i.Addrs[0].Addr, nil
 			}
-			log.Debugf("domain %s with MAC address %s doesn't have current IP address in network %s: %+v", domain, mac, network, i)
+			log.Debugf("domain %s with MAC address %s doesn't have current IP address in network %s: %+v", domain, mac, networkName, i)
 			return "", nil
 		}
 	}
 
-	log.Debugf("unable to find current IP address of domain %s in network %s", domain, network)
+	log.Debugf("unable to find current IP address of domain %s in network %s (interfaces detected: %+v)", domain, networkName, ifaces)
 	return "", nil
 }
 
@@ -499,22 +548,27 @@ func ipFromAPI(conn *libvirt.Connect, domain, network string) (string, error) {
 func ifListFromAPI(conn *libvirt.Connect, domain string) ([]libvirt.DomainInterface, error) {
 	dom, err := conn.LookupDomainByName(domain)
 	if err != nil {
-		return nil, fmt.Errorf("failed looking up domain %s: %w", domain, err)
+		return nil, fmt.Errorf("failed looking up domain %s: %w", domain, lvErr(err))
 	}
-	defer func() { _ = dom.Free() }()
-
-	ifs, err := dom.ListAllInterfaceAddresses(libvirt.DOMAIN_INTERFACE_ADDRESSES_SRC_ARP)
-	if ifs == nil {
-		if err != nil {
-			log.Debugf("failed listing network interface addresses of domain %s(source=arp): %w", domain, err)
-		} else {
-			log.Debugf("No network interface addresses found for domain %s(source=arp)", domain)
+	defer func() {
+		if dom == nil {
+			log.Warnf("nil domain, cannot free")
+		} else if err := dom.Free(); err != nil {
+			log.Errorf("failed freeing %s domain: %v", domain, lvErr(err))
 		}
-		log.Debugf("trying to list again with source=lease")
+	}()
 
-		ifs, err = dom.ListAllInterfaceAddresses(libvirt.DOMAIN_INTERFACE_ADDRESSES_SRC_LEASE)
+	ifs, err := dom.ListAllInterfaceAddresses(libvirt.DOMAIN_INTERFACE_ADDRESSES_SRC_LEASE)
+	if len(ifs) == 0 {
 		if err != nil {
-			return nil, fmt.Errorf("failed listing network interface addresses of domain %s(source=lease): %w", domain, err)
+			log.Debugf("failed listing network interface addresses of domain %s (source=lease): %v", domain, lvErr(err))
+		} else {
+			log.Debugf("no network interface addresses found for domain %s (source=lease)", domain)
+		}
+		log.Debugf("trying to list again with source=arp")
+
+		if ifs, err = dom.ListAllInterfaceAddresses(libvirt.DOMAIN_INTERFACE_ADDRESSES_SRC_ARP); err != nil {
+			return nil, fmt.Errorf("failed listing network interface addresses of domain %s (source=arp): %w", domain, lvErr(err))
 		}
 	}
 
@@ -522,40 +576,40 @@ func ifListFromAPI(conn *libvirt.Connect, domain string) ([]libvirt.DomainInterf
 }
 
 // ipFromXML returns defined IP address of interface in network.
-func ipFromXML(conn *libvirt.Connect, domain, network string) (string, error) {
-	mac, err := macFromXML(conn, domain, network)
+func ipFromXML(conn *libvirt.Connect, domain, networkName string) (string, error) {
+	mac, err := macFromXML(conn, domain, networkName)
 	if err != nil {
 		return "", fmt.Errorf("failed getting MAC address: %w", err)
 	}
 
-	lease, err := dhcpLease(conn, network, "", mac, "")
+	lease, err := dhcpLease(conn, networkName, "", mac, "")
 	if err != nil {
-		return "", fmt.Errorf("failed looking up network %s for host DHCP lease {name: <any>, mac: %q, ip: <any>}: %w", network, mac, err)
+		return "", fmt.Errorf("failed looking up network %s for host DHCP lease {name: <any>, mac: %q, ip: <any>}: %w", networkName, mac, err)
 	}
 	if lease == nil {
-		log.Debugf("unable to find defined IP address of network %s interface with MAC address %s", network, mac)
+		log.Debugf("unable to find defined IP address of network %s interface with MAC address %s", networkName, mac)
 		return "", nil
 	}
 
-	log.Debugf("domain %s has defined IP address %s and MAC address %s in network %s", domain, lease.IPaddr, mac, network)
+	log.Debugf("domain %s has defined IP address %s and MAC address %s in network %s", domain, lease.IPaddr, mac, networkName)
 	return lease.IPaddr, nil
 }
 
 // macFromXML returns defined MAC address of interface in network from domain XML.
-func macFromXML(conn *libvirt.Connect, domain, network string) (string, error) {
+func macFromXML(conn *libvirt.Connect, domain, networkName string) (string, error) {
 	domIfs, err := ifListFromXML(conn, domain)
 	if err != nil {
-		return "", fmt.Errorf("failed getting network %s interfaces using XML of domain %s: %w", network, domain, err)
+		return "", fmt.Errorf("failed getting network %s interfaces using XML of domain %s: %w", networkName, domain, err)
 	}
 
 	for _, i := range domIfs {
-		if i.Source.Network == network {
-			log.Debugf("domain %s has defined MAC address %s in network %s", domain, i.Mac.Address, network)
+		if i.Source.Network == networkName {
+			log.Debugf("domain %s has defined MAC address %s in network %s", domain, i.Mac.Address, networkName)
 			return i.Mac.Address, nil
 		}
 	}
 
-	return "", fmt.Errorf("unable to get defined MAC address of network %s interface using XML of domain %s: network %s not found", network, domain, network)
+	return "", fmt.Errorf("unable to get defined MAC address of network %s interface using XML of domain %s: network %s not found", networkName, domain, networkName)
 }
 
 // ifListFromXML returns defined domain interfaces from domain XML.
@@ -564,7 +618,13 @@ func ifListFromXML(conn *libvirt.Connect, domain string) ([]kvmIface, error) {
 	if err != nil {
 		return nil, fmt.Errorf("failed looking up domain %s: %w", domain, err)
 	}
-	defer func() { _ = dom.Free() }()
+	defer func() {
+		if dom == nil {
+			log.Warnf("nil domain, cannot free")
+		} else if err := dom.Free(); err != nil {
+			log.Errorf("failed freeing %s domain: %v", domain, lvErr(err))
+		}
+	}()
 
 	domXML, err := dom.GetXMLDesc(0)
 	if err != nil {
