@@ -41,7 +41,7 @@ import (
 	"github.com/pkg/errors"
 
 	"k8s.io/klog/v2"
-	pkgdrivers "k8s.io/minikube/pkg/drivers"
+	"k8s.io/minikube/pkg/drivers/common"
 	"k8s.io/minikube/pkg/minikube/detect"
 	"k8s.io/minikube/pkg/minikube/exit"
 	"k8s.io/minikube/pkg/minikube/firewall"
@@ -54,6 +54,7 @@ import (
 
 const (
 	isoFilename        = "boot2docker.iso"
+	serialFileName     = "serial.log"
 	privateNetworkName = "docker-machines"
 
 	defaultSSHUser = "docker"
@@ -61,7 +62,7 @@ const (
 
 type Driver struct {
 	*drivers.BaseDriver
-	*pkgdrivers.CommonDriver
+	*common.CommonDriver
 	EnginePort int
 	FirstQuery bool
 
@@ -285,8 +286,8 @@ func (d *Driver) Create() error {
 	if d.ExtraDisks > 0 {
 		log.Info("Creating extra disk images...")
 		for i := 0; i < d.ExtraDisks; i++ {
-			path := pkgdrivers.ExtraDiskPath(d.BaseDriver, i)
-			if err := pkgdrivers.CreateRawDisk(path, d.DiskSize); err != nil {
+			path := common.ExtraDiskPath(d.BaseDriver, i)
+			if err := common.CreateRawDisk(path, d.DiskSize); err != nil {
 				return err
 			}
 		}
@@ -464,12 +465,16 @@ func (d *Driver) Start() error {
 			"virtio-9p-pci,id=fs0,fsdev=fsdev0,mount_tag=config-2")
 	}
 
+	serialPath := d.ResolveStorePath(serialFileName)
+	startCmd = append(startCmd,
+		"-serial", fmt.Sprintf("file:%s", serialPath))
+
 	for i := 0; i < d.ExtraDisks; i++ {
 		// use a higher index for extra disks to reduce ID collision with current or future
 		// low-indexed devices (e.g., firmware, ISO CDROM, cloud config, and network device)
 		index := i + 10
 		startCmd = append(startCmd,
-			"-drive", fmt.Sprintf("file=%s,index=%d,media=disk,format=raw,if=virtio", pkgdrivers.ExtraDiskPath(d.BaseDriver, i), index),
+			"-drive", fmt.Sprintf("file=%s,index=%d,media=disk,format=raw,if=virtio", common.ExtraDiskPath(d.BaseDriver, i), index),
 		)
 	}
 
@@ -505,14 +510,18 @@ func (d *Driver) Start() error {
 	case "socket_vmnet":
 		var err error
 		getIP := func() error {
-			d.IPAddress, err = pkgdrivers.GetIPAddressByMACAddress(d.MACAddress)
+			d.IPAddress, err = common.GetIPAddressByMACAddress(d.MACAddress)
 			if err != nil {
 				return errors.Wrap(err, "failed to get IP address")
 			}
 			return nil
 		}
 		// Implement a retry loop because IP address isn't added to dhcp leases file immediately
-		for i := 0; i < 60; i++ {
+		multiplier := 1
+		if detect.NestedVM() {
+			multiplier = 3 // will help with running in Free github action Macos VMs (takes 112+ retries on average)
+		}
+		for i := 0; i < 60*multiplier; i++ {
 			log.Debugf("Attempt %d", i)
 			err = getIP()
 			if err == nil {
