@@ -48,21 +48,21 @@ var (
 )
 
 // ClientConfig returns the client configuration for a kubectl context
-func ClientConfig(context string) (*rest.Config, error) {
+func ClientConfig(ctx string) (*rest.Config, error) {
 	loader := clientcmd.NewDefaultClientConfigLoadingRules()
-	cc := clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loader, &clientcmd.ConfigOverrides{CurrentContext: context})
+	cc := clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loader, &clientcmd.ConfigOverrides{CurrentContext: ctx})
 	c, err := cc.ClientConfig()
 	if err != nil {
 		return nil, fmt.Errorf("client config: %v", err)
 	}
 	c = proxy.UpdateTransport(c)
-	klog.V(1).Infof("client config for %s: %+v", context, c)
+	klog.V(1).Infof("client config for %s: %+v", ctx, c)
 	return c, nil
 }
 
 // Client gets the Kubernetes client for a kubectl context name
-func Client(context string) (*kubernetes.Clientset, error) {
-	c, err := ClientConfig(context)
+func Client(ctx string) (*kubernetes.Clientset, error) {
+	c, err := ClientConfig(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -108,40 +108,6 @@ func WaitForPods(c kubernetes.Interface, ns string, selector string, timeOut ...
 	return err
 }
 
-// WaitForRCToStabilize waits till the RC has a matching generation/replica count between spec and status. used by integration tests
-func WaitForRCToStabilize(c kubernetes.Interface, ns, name string, timeout time.Duration) error {
-	options := meta.ListOptions{FieldSelector: fields.Set{
-		"metadata.name":      name,
-		"metadata.namespace": ns,
-	}.AsSelector().String()}
-
-	ctx, cancel := watchtools.ContextWithOptionalTimeout(context.Background(), timeout)
-	defer cancel()
-
-	w, err := c.CoreV1().ReplicationControllers(ns).Watch(ctx, options)
-	if err != nil {
-		return err
-	}
-	_, err = watchtools.UntilWithoutRetry(ctx, w, func(event watch.Event) (bool, error) {
-		if event.Type == watch.Deleted {
-			return false, apierr.NewNotFound(schema.GroupResource{Resource: "replicationcontrollers"}, "")
-		}
-
-		rc, ok := event.Object.(*core.ReplicationController)
-		if ok {
-			if rc.Name == name && rc.Namespace == ns &&
-				rc.Generation <= rc.Status.ObservedGeneration &&
-				*(rc.Spec.Replicas) == rc.Status.Replicas {
-				return true, nil
-			}
-			klog.Infof("Waiting for rc %s to stabilize, generation %v observed generation %v spec.replicas %d status.replicas %d",
-				name, rc.Generation, rc.Status.ObservedGeneration, *(rc.Spec.Replicas), rc.Status.Replicas)
-		}
-		return false, nil
-	})
-	return err
-}
-
 // WaitForDeploymentToStabilize waits till the Deployment has a matching generation/replica count between spec and status. used by integration tests
 func WaitForDeploymentToStabilize(c kubernetes.Interface, ns, name string, timeout time.Duration) error {
 	options := meta.ListOptions{FieldSelector: fields.Set{
