@@ -34,7 +34,7 @@ func (c Disabled) String() string {
 }
 
 // Apply enables the CNI
-func (c Disabled) Apply(r Runner) error {
+func (c Disabled) Apply(_ Runner) error {
 	if driver.IsKIC(c.cc.Driver) && c.cc.KubernetesConfig.ContainerRuntime != constants.Docker {
 		klog.Warningf("CNI is recommended for %q driver and %q runtime - expect networking issues", c.cc.Driver, c.cc.KubernetesConfig.ContainerRuntime)
 	}
