@@ -21,6 +21,17 @@ package constants
 // ValidKubernetesVersions is a list of Kubernetes versions in order from newest to oldest
 // This is used when outputting Kubernetes versions and to select the latest patch version when unspecified
 var ValidKubernetesVersions = []string{
+	"v1.34.0",
+	"v1.34.0-rc.2",
+	"v1.34.0-rc.1",
+	"v1.34.0-rc.0",
+	"v1.34.0-beta.0",
+	"v1.34.0-alpha.3",
+	"v1.34.0-alpha.2",
+	"v1.34.0-alpha.1",
+	"v1.33.4",
+	"v1.33.3",
+	"v1.33.2",
 	"v1.33.1",
 	"v1.33.0",
 	"v1.33.0-rc.1",
@@ -29,6 +40,9 @@ var ValidKubernetesVersions = []string{
 	"v1.33.0-alpha.3",
 	"v1.33.0-alpha.2",
 	"v1.33.0-alpha.1",
+	"v1.32.8",
+	"v1.32.7",
+	"v1.32.6",
 	"v1.32.5",
 	"v1.32.4",
 	"v1.32.3",
@@ -42,6 +56,9 @@ var ValidKubernetesVersions = []string{
 	"v1.32.0-alpha.3",
 	"v1.32.0-alpha.2",
 	"v1.32.0-alpha.1",
+	"v1.31.12",
+	"v1.31.11",
+	"v1.31.10",
 	"v1.31.9",
 	"v1.31.8",
 	"v1.31.7",
@@ -58,6 +75,7 @@ var ValidKubernetesVersions = []string{
 	"v1.31.0-alpha.3",
 	"v1.31.0-alpha.2",
 	"v1.31.0-alpha.1",
+	"v1.30.14",
 	"v1.30.13",
 	"v1.30.12",
 	"v1.30.11",
