@@ -28,6 +28,9 @@ var supportedDrivers = func() []string {
 		// on darwin/arm64 only docker and ssh are supported yet
 		return []string{
 			QEMU2,
+			VFKit,
+			Krunkit,
+			Parallels,
 			Docker,
 			Podman,
 			SSH,
@@ -50,6 +53,7 @@ var supportedDrivers = func() []string {
 		HyperKit,
 		VMware,
 		QEMU2,
+		VFKit,
 		Docker,
 		Podman,
 		SSH,
