@@ -26,6 +26,7 @@ import (
 	"strings"
 	"time"
 
+	cerrdefs "github.com/containerd/errdefs"
 	"github.com/docker/docker/client"
 	"github.com/google/go-containerregistry/pkg/authn"
 	"github.com/google/go-containerregistry/pkg/name"
@@ -72,9 +73,11 @@ func DigestByDockerLib(imgClient *client.Client, imgName string) string {
 	ctx, cancel := context.WithTimeout(context.Background(), time.Second*10)
 	defer cancel()
 	imgClient.NegotiateAPIVersion(ctx)
-	img, _, err := imgClient.ImageInspectWithRaw(ctx, imgName)
-	if err != nil && !client.IsErrNotFound(err) {
-		klog.Infof("couldn't find image digest %s from local daemon: %v ", imgName, err)
+	img, err := imgClient.ImageInspect(ctx, imgName)
+	if err != nil {
+		if !cerrdefs.IsNotFound(err) {
+			klog.Infof("couldn't find image digest %s from local daemon: %v ", imgName, err)
+		}
 		return ""
 	}
 	return img.ID
@@ -340,6 +343,6 @@ func normalizeTagName(image string) string {
 
 // Remove docker.io prefix since it won't be included in image names
 // when we call `docker images`.
-func TrimDockerIO(name string) string {
-	return strings.TrimPrefix(name, "docker.io/")
+func TrimDockerIO(imageName string) string {
+	return strings.TrimPrefix(imageName, "docker.io/")
 }
