@@ -18,9 +18,11 @@ package node
 
 import (
 	"fmt"
+	"maps"
 	"os"
 	"path"
 	"runtime"
+	"slices"
 	"strings"
 
 	"k8s.io/minikube/pkg/minikube/detect"
@@ -188,15 +190,18 @@ func beginDownloadKicBaseImage(g *errgroup.Group, cc *config.ClusterConfig, down
 		out.Ln("")
 
 		kicbaseVersion := strings.Split(kic.Version, "-")[0]
-		finalImg, err = download.GHImageTarballToCache("kicbase", kicbaseVersion)
+		_, err = download.GHKicbaseTarballToCache(kicbaseVersion)
 		if err != nil {
-			klog.Infof("failed to download %s", finalImg)
+			klog.Infof("failed to download kicbase from github")
 			return fmt.Errorf("failed to download kic base image or any fallback image")
 		}
-		klog.Infof("successfully downloaded %s as fall back image", finalImg)
+
+		klog.Infof("successfully downloaded kicbase as fall back image from github")
 		if !downloadOnly && driver.IsDocker(cc.Driver) {
-			if finalImg, err = download.CacheToDaemon("kicbase"); err == nil {
+			if finalImg, err = download.CacheToDaemon(fmt.Sprintf("kicbase/stable:%s", kicbaseVersion)); err == nil {
 				klog.Infof("successfully loaded and using kicbase from tarball on github")
+			} else {
+				return fmt.Errorf("failed to load kic base image into docker: %v", err)
 			}
 		}
 		return nil
@@ -269,22 +274,21 @@ func imagesInConfigFile() ([]string, error) {
 		return nil, errors.Wrap(err, "read")
 	}
 	if values, ok := configFile[cacheImageConfigKey]; ok {
-		var images []string
-		for key := range values.(map[string]interface{}) {
-			images = append(images, key)
-		}
+		// Type assertion needed because config values are stored as interface{}
+		m := values.(map[string]interface{})
+		images := slices.Collect(maps.Keys(m))
 		return images, nil
 	}
 	return []string{}, nil
 }
 
 func updateKicImageRepo(imgName string, repo string) string {
-	image := strings.TrimPrefix(imgName, "gcr.io/")
+	imageName := strings.TrimPrefix(imgName, "gcr.io/")
 	if repo == constants.AliyunMirror {
 		// for aliyun registry must strip namespace from image name, e.g.
 		//   registry.cn-hangzhou.aliyuncs.com/google_containers/k8s-minikube/kicbase:v0.0.25 will not work
 		//   registry.cn-hangzhou.aliyuncs.com/google_containers/kicbase:v0.0.25 does work
-		image = strings.TrimPrefix(image, "k8s-minikube/")
+		imageName = strings.TrimPrefix(imageName, "k8s-minikube/")
 	}
-	return path.Join(repo, image)
+	return path.Join(repo, imageName)
 }
