@@ -66,9 +66,11 @@ var (
 	// JSON is whether or not we should output stdout in JSON format. Set using SetJSON()
 	JSON = false
 	// spin is spinner showed at starting minikube
-	spin = spinner.New(spinner.CharSets[style.SpinnerCharacter], 100*time.Millisecond)
+	spin = spinner.New(spinner.CharSets[style.SpinnerCharacter], 100*time.Millisecond, spinner.WithWriter(outFile))
 	// defaultBoxCfg is the default style config for cli box output
 	defaultBoxCfg = box.Config{Py: 1, Px: 4, Type: "Round", Color: "Red"}
+	// alreadyShoweddGitHubIssueMessage is used to prevent showing the GitHub issue message multiple times
+	alreadyShoweddGitHubIssueMessage = false
 )
 
 // MaxLogEntries controls the number of log entries to show for each source
@@ -91,7 +93,7 @@ func Step(st style.Enum, format string, a ...V) {
 		Infof(format, a...)
 		return
 	}
-	outStyled, _ := stylized(st, useColor, format, a...)
+	outStyled, _, _ := stylized(st, useColor, format, a...)
 	if JSON {
 		register.PrintStep(outStyled)
 		klog.Info(outStyled)
@@ -107,21 +109,21 @@ func Styled(st style.Enum, format string, a ...V) {
 		Infof(format, a...)
 		return
 	}
-	outStyled, spinner := stylized(st, useColor, format, a...)
-	if spinner {
-		spinnerString(outStyled)
+	outStyled, useSpinner, hideAfterSpin := stylized(st, useColor, format, a...)
+	if useSpinner {
+		spinnerString(outStyled, hideAfterSpin)
 	} else {
 		String(outStyled)
 	}
 }
 
 func boxedCommon(printFunc func(format string, a ...interface{}), cfg box.Config, title string, format string, a ...V) {
-	box := box.New(cfg)
+	b := box.New(cfg)
 	if !useColor {
-		box.Config.Color = nil
+		b.Config.Color = nil
 	}
 	str := Sprintf(style.None, format, a...)
-	printFunc(box.String(title, strings.TrimSpace(str)))
+	printFunc(b.String(title, strings.TrimSpace(str)))
 }
 
 // Boxed writes a stylized and templated message in a box to stdout using the default style config
@@ -146,13 +148,13 @@ func BoxedWithConfig(cfg box.Config, st style.Enum, title string, text string, a
 
 // Sprintf is used for returning the string (doesn't write anything)
 func Sprintf(st style.Enum, format string, a ...V) string {
-	outStyled, _ := stylized(st, useColor, format, a...)
+	outStyled, _, _ := stylized(st, useColor, format, a...)
 	return outStyled
 }
 
 // Infof is used for informational logs (options, env variables, etc)
 func Infof(format string, a ...V) {
-	outStyled, _ := stylized(style.Option, useColor, format, a...)
+	outStyled, _, _ := stylized(style.Option, useColor, format, a...)
 	if JSON {
 		register.PrintInfo(outStyled)
 	}
@@ -214,6 +216,21 @@ func Output(file fdWriter, s string) {
 	}
 }
 
+// outputSpining writes a basic string with spinining
+func outputSpining(file fdWriter, s string, hideAfterSpin bool) {
+	spin.Writer = file
+	spin.Prefix = s
+	if hideAfterSpin {
+		spin.UpdateCharSet(spinner.CharSets[style.SpinnerSubStepCharacter])
+		spin.FinalMSG = ""
+	} else {
+		spin.UpdateCharSet(spinner.CharSets[style.SpinnerCharacter])
+		spin.FinalMSG = s + "\n"
+	}
+	spin.Start()
+
+}
+
 // Outputf writes a basic formatted string
 func Outputf(file fdWriter, format string, a ...interface{}) {
 	_, err := fmt.Fprintf(file, format, a...)
@@ -223,7 +240,7 @@ func Outputf(file fdWriter, format string, a ...interface{}) {
 }
 
 // spinnerString writes a basic formatted string to stdout with spinner character
-func spinnerString(s string) {
+func spinnerString(s string, hideAfterSpin bool) {
 	// Flush log buffer so that output order makes sense
 	klog.Flush()
 
@@ -237,9 +254,7 @@ func spinnerString(s string) {
 	if spin.Active() {
 		spin.Stop()
 	}
-	Output(outFile, s)
-	// Start spinning at the end of the printed line
-	spin.Start()
+	outputSpining(outFile, s, hideAfterSpin)
 }
 
 // Ln writes a basic formatted string with a newline to stdout
@@ -249,7 +264,7 @@ func Ln(format string, a ...interface{}) {
 
 // ErrT writes a stylized and templated error message to stderr
 func ErrT(st style.Enum, format string, a ...V) {
-	errStyled, _ := stylized(st, useColor, format, a...)
+	errStyled, _, _ := stylized(st, useColor, format, a...)
 	Err(errStyled)
 }
 
@@ -316,7 +331,7 @@ func WarningT(format string, a ...V) {
 		if spin.Active() {
 			spin.Stop()
 		}
-		st, _ := stylized(style.Warning, useColor, format, a...)
+		st, _, _ := stylized(style.Warning, useColor, format, a...)
 		register.PrintWarning(st)
 		klog.Warning(st)
 		return
@@ -343,6 +358,7 @@ func SetSilent(q bool) {
 // SetOutFile configures which writer standard output goes to.
 func SetOutFile(w fdWriter) {
 	klog.Infof("Setting OutFile to fd %d ...", w.Fd())
+	spin.Writer = w
 	outFile = w
 	useColor = wantsColor(w)
 }
@@ -463,6 +479,9 @@ func command() (string, error) {
 }
 
 func displayGitHubIssueMessage() {
+	if alreadyShoweddGitHubIssueMessage {
+		return
+	}
 	cmd, err := command()
 	if err != nil {
 		klog.Warningf("failed to get command: %v", err)
@@ -482,6 +501,7 @@ func displayGitHubIssueMessage() {
 	}
 
 	BoxedErr(msg)
+	alreadyShoweddGitHubIssueMessage = true
 }
 
 // applyTmpl applies formatting
