@@ -552,15 +552,11 @@ var (
 	NotFoundVmnetHelper = Kind{
 		ID:       "NOT_FOUND_VMNET_HELPER",
 		ExitCode: ExProgramNotFound,
-		Advice: translate.T(`vmnet-helper was not found on the system, resolve by:
+		Advice: translate.T(`vmnet-helper was not found on the system.
 
-		Option 1) Installing vmnet-helper:
+		Please install vmnet-helper using these instructions:
 
-		  https://github.com/nirs/vmnet-helper#installation
-
-		Option 2) Using the nat network:
-
-		  minikube start{{.profile}} --driver vfkit --network nat`),
+			curl -fsSL https://github.com/minikube-machine/vmnet-helper/releases/latest/download/install.sh | bash`),
 		Style: style.SeeNoEvil,
 	}
 	NotConfiguredVmnetHelper = Kind{
@@ -569,8 +565,7 @@ var (
 		Advice: translate.T(`Configure vmnet-helper to run without a password.
 
 		Please install a vmnet-helper sudoers rule using these instructions:
-
-		https://github.com/nirs/vmnet-helper#granting-permission-to-run-vmnet-helper`),
+			curl -fsSL https://github.com/minikube-machine/vmnet-helper/releases/latest/download/install.sh | bash`),
 		Style: style.SeeNoEvil,
 	}
 )
