@@ -110,10 +110,19 @@ func (s *Systemd) Restart(svc string) error {
 	if err := s.daemonReload(); err != nil {
 		return err
 	}
+
 	_, err := s.r.RunCmd(exec.Command("sudo", "systemctl", "restart", svc))
 	return s.appendJournalctlLogsOnFailure(svc, err)
 }
 
+// run systemctl reset-failed for a service
+// some services declare a realitive small restart-limit in their .service configuration
+// so we reset reset-failed counter to override the limit
+func (s *Systemd) ResetFailed(svc string) error {
+	_, err := s.r.RunCmd(exec.Command("sudo", "systemctl", "reset-failed", svc))
+	return s.appendJournalctlLogsOnFailure(svc, err)
+}
+
 // Reload reloads a service
 func (s *Systemd) Reload(svc string) error {
 	if err := s.daemonReload(); err != nil {
