@@ -68,7 +68,7 @@ func (r *simpleReporter) Report(tunnelState *Status) {
 		loadbalancer emulator: %s
 `, minikubeError, routerError, lbError)
 
-	_, err := r.out.Write([]byte(fmt.Sprintf(
+	_, err := fmt.Fprintf(r.out,
 		`Status:	
 	machine: %s
 	pid: %d
@@ -80,7 +80,7 @@ func (r *simpleReporter) Report(tunnelState *Status) {
 		tunnelState.TunnelID.Route,
 		minikubeState,
 		managedServices,
-		errors)))
+		errors)
 	if err != nil {
 		klog.Errorf("failed to report state %s", err)
 	}
