@@ -23,6 +23,7 @@ import (
 	"os/exec"
 	"path"
 	"path/filepath"
+	"slices"
 	"strings"
 	"text/template"
 	"time"
@@ -83,7 +84,7 @@ func configureAuth(p miniProvisioner) error {
 	klog.Infof("configureAuth start")
 	start := time.Now()
 	defer func() {
-		klog.Infof("duration metric: configureAuth took %s", time.Since(start))
+		klog.Infof("duration metric: took %s to configureAuth", time.Since(start))
 	}()
 
 	driver := p.GetDriver()
@@ -109,6 +110,10 @@ func configureAuth(p miniProvisioner) error {
 	hosts := authOptions.ServerCertSANs
 	// The Host IP is always added to the certificate's SANs list
 	hosts = append(hosts, ip, hostIP, "localhost", "127.0.0.1", "minikube", machineName)
+	// eliminate duplicates in 'hosts'
+	slices.Sort(hosts)
+	hosts = slices.Compact(hosts)
+
 	klog.Infof("generating server cert: %s ca-key=%s private-key=%s org=%s san=%s",
 		authOptions.ServerCertPath,
 		authOptions.CaCertPath,
